@@ -1,7 +1,7 @@
 import streamlit.components.v1 as components
 import os
 
-_RELEASE = False
+_RELEASE = True
 
 
 if not _RELEASE:
